@@ -3,7 +3,7 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -247,14 +247,14 @@ class LoginDlg(KDialog):
 
     def __init__(self) ->None:
         """self.servers is a list of tuples containing server and last playername"""
-        KDialog.__init__(self, None)
+        super().__init__(None)
         decorateWindow(self, i18nc('kajongg', 'Login'))
         self.setupUi()
 
         localName = i18nc('kajongg name for local game server', Query.localServerName)
-        self.servers = Query(
-            'select url,lastname from server order by lasttime desc').records
-        servers = [x[0] for x in self.servers if x[0] != Query.localServerName]
+        self._servers = Query(
+            'select {fields} from server order by lasttime desc', fields='url, lastname as playername').tuples()
+        servers = [x.url for x in self._servers if x.url != Query.localServerName]
         # the first server combobox item should be default: either the last used server
         # or localName for autoPlay
         if localName not in servers:
@@ -289,7 +289,8 @@ class LoginDlg(KDialog):
         # Ubuntu 11.10 unity is a bit strange - without this, it sets focus on
         # the cancel button (which it shows on the left). I found no obvious
         # way to use setDefault and setAutoDefault for fixing this.
-        self.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setFocus()
+        if button := self.buttonBox.button(QDialogButtonBox.StandardButton.Ok):
+            button.setFocus()
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.reject)
         vbox = QVBoxLayout(self)
@@ -313,9 +314,8 @@ class LoginDlg(KDialog):
 
     def serverChanged(self, unusedText:Optional[str]=None) ->None:
         """the user selected a different server"""
-        records = Query('select player.name from player, passwords '
-                        'where passwords.url=? and passwords.player = player.id', (self.url,)).records
-        players = [x[0] for x in records]
+        players = Query('select player.name from player, passwords '
+                        'where passwords.url=? and passwords.player = player.id', (self.url,)).column(0)
         preferPlayer = Options.player
         if preferPlayer:
             if preferPlayer in players:
@@ -327,17 +327,17 @@ class LoginDlg(KDialog):
             user = KUser() if sys.platform == 'win32' else KUser(os.geteuid())
             self.cbUser.addItem(user.fullName() or user.loginName())
         if not preferPlayer:
-            userNames = [x[1] for x in self.servers if x[0] == self.url]
+            userNames = [x.playername for x in self._servers if x.url == self.url]
             if userNames:
                 userIdx = self.cbUser.findText(userNames[0])
                 if userIdx >= 0:
                     self.cbUser.setCurrentIndex(userIdx)
         showPW = bool(self.url) and not Url(self.url).isLocalHost
-        self.grid.labelForField(self.edPassword).setVisible(showPW)
+        if label := self.grid.labelForField(self.edPassword):
+            label.setVisible(showPW)
         self.edPassword.setVisible(showPW)
-        self.grid.labelForField(
-            self.cbRuleset).setVisible(
-                not showPW and not Options.ruleset)
+        if label := self.grid.labelForField(self.cbRuleset):
+            label.setVisible( not showPW and not Options.ruleset)
         self.cbRuleset.setVisible(not showPW and not Options.ruleset)
         if not showPW:
             self.cbRuleset.clear()
@@ -345,7 +345,8 @@ class LoginDlg(KDialog):
                 self.cbRuleset.items = [Options.ruleset]
             else:
                 self.cbRuleset.items = Ruleset.selectableRulesets(self.url)
-        self.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setEnabled(bool(self.url))
+        if button := self.buttonBox.button(QDialogButtonBox.StandardButton.Ok):
+            button.setEnabled(bool(self.url))
 
     def __defineRuleset(self) ->'Ruleset':
         """find out what ruleset to use"""
@@ -395,7 +396,7 @@ class AddUserDialog(KDialog):
     """add a user account on a server: This dialog asks for the needed attributes"""
 
     def __init__(self, url:str, username:str, password:str):
-        KDialog.__init__(self)
+        super().__init__()
         decorateWindow(self, i18nc("@title:window", "Create User Account"))
         self.setButtons(KDialog.Ok | KDialog.Cancel)
         vbox = QVBoxLayout()
@@ -646,13 +647,14 @@ class Connection:
 
     def ping(self) ->None:
         """regularly check if server is still there"""
+        def disconnected(unusedResult:Any) ->None:
+            self.client.remote_serverDisconnects()
         if self.client.connection:
             # when pinging starts, we do have a connection and when the
             # connection goes away, it does not come back
             self.client.callServer(
                 'ping').addCallback(
-                    self.pingLater).addErrback(
-                        self.client.remote_serverDisconnects)
+                    self.pingLater).addErrback(disconnected)
 
     def __str__(self) ->str:
         return f'{self.username}@{self.url}'
