@@ -3,7 +3,7 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -63,7 +63,7 @@ class Players(list, ReprMixin):
                 if player.wind == index:
                     return player
         assert isinstance(index, (int, slice)), f'index is neither Wind, int nor slice:{type(index)}'
-        return list.__getitem__(self, index)
+        return super().__getitem__(index)
 
     def __str__(self) ->str:
         return ', '.join(f'{x.name}: {x.wind}' for x in self)
@@ -307,11 +307,11 @@ class Player(ReprMixin):
     def lastSource(self, value: Type[TileSource.SourceClass]) ->None:
         """the source of the last tile the player got"""
         if self.game:
-            assert self.game.wall
-            if value is TileSource.LivingWallDiscard and not self.game.wall.living:
-                value = TileSource.LivingWallEndDiscard
-            if value is TileSource.LivingWall and not self.game.wall.living:
-                value = TileSource.LivingWallEnd
+            if self.game.wall:
+                if value is TileSource.LivingWallDiscard and not self.game.wall.living:
+                    value = TileSource.LivingWallEndDiscard
+                if value is TileSource.LivingWall and not self.game.wall.living:
+                    value = TileSource.LivingWallEnd
         if self.__lastSource != value:
             self.__lastSource = value
             self._hand = None
@@ -408,7 +408,7 @@ class Player(ReprMixin):
     def colorizeName(self) ->None:
         """virtual: colorize Name on wall"""
 
-    def getsFocus(self, unusedResults:Optional[List['Request']]=None) ->None:
+    def getsFocus(self, unusedResults:Any=None) ->None:
         """virtual: player gets focus on his hand"""
 
     def __announcements(self) -> Set:
@@ -417,7 +417,7 @@ class Player(ReprMixin):
 
     def makeTileKnown(self, tile:Tile) -> None:
         """used when somebody else discards a tile"""
-        assert not self._concealedTiles[0].isKnown
+        assert not self._concealedTiles[0].isKnown, f'{self._concealedTiles=}{self._concealedTiles[0].isKnown=}'
         self._concealedTiles[0] = tile
         self._hand = None
 
@@ -515,7 +515,7 @@ class PlayingPlayer(Player):  # pylint:disable=too-many-instance-attributes
         # recompute sayable for each move, use as cache
         self.voice:Optional['Voice']
         self.game:Optional['PlayingGame']
-        Player.__init__(self, game, name)
+        super().__init__(game, name)
 
     def popupMsg(self, msg:'Message') ->None:
         """virtual: show popup on display"""
@@ -703,8 +703,7 @@ class PlayingPlayer(Player):  # pylint:disable=too-many-instance-attributes
             for tileName in tiles:
                 src, dst = (Tile.unknown, tileName) if show else (
                     tileName, Tile.unknown)
-                assert src != dst, (
-                    self, src, dst, tiles, self._concealedTiles)
+                assert src != dst, f'{self=} {src=} {dst=} {tiles=} {self._concealedTiles=}'
                 if src not in self._concealedTiles:
                     logException(f'{self}: showConcealedTiles({tiles}): {src} not in {self._concealedTiles}.')
                 idx = self._concealedTiles.index(src)
@@ -737,7 +736,7 @@ class PlayingPlayer(Player):  # pylint:disable=too-many-instance-attributes
         self._hand = None
         return None
 
-    def robTileFrom(self, tile:Tile) -> None:
+    def getsRobbed(self, tile:Tile) -> None:
         """used for robbing the kong from this player"""
         if Debug.robbingKong:
             logDebug(f'robbed {tile} from {self}')
@@ -750,7 +749,7 @@ class PlayingPlayer(Player):  # pylint:disable=too-many-instance-attributes
                 break
         else:
             # TODO: should we somehow show an error and continue?
-            raise ValueError(f'robTileFrom: no meld found with {tile}')
+            raise ValueError(f'getsRobbed: no meld found with {tile}')
         assert self.game
         self.game.lastDiscard = tile.concealed
         self.lastTile = Tile.none  # our lastTile has just been robbed
